export const commonStyle = {
    rotate: 0,
    opacity: 1
}

export const commonAttr = {
    // 当一个组件成为 Group 的子组件时使用
    groupStyle: {},
    // 是否锁定组件
    isLock: false
}

/**
 * 布局组件:
 */
export const layoutComponentList = [
    {name: "标题", code: "title"},
    {name: "页头", code: "page_header"},
    {name: "列头", code: "column_header"},
    {name: "详细", code: "detail"},
    {name: "列脚", code: "column_footer"},
    {name: "页脚", code: "page_footer"},
    {name: "最后一页页脚", code: "last_page_footer"},
    {name: "统计", code: "summary"},
]

/**
 * 基础组件
 */
export const basicComponentList = [
    {
        icon: 'fa fa-file-text-o',
        code: 'text',
        name: '文本',
        component: 'YvanSimpleText',
        propValue: '单击编辑文本',
        style: {
            color: '#000000',
            borderRadius: 'inherit',
            padding: '0',
            margin: '0',
            fontFamily: 'default',
            lineHeight: '1',
            letterSpacing: '0',
            borderWidth: 0,
            borderColor: '#212121',
            borderType: 'none',
            width: 200,
            height: 50,
            fontSize: 10,
            background: null,
            rotate: 0,
            justifyContent: 'flex-start',
            alignItems: 'flex-start',
            fontWeight: 'normal',
            fontStyle: 'normal',
            isUnderLine: false,
            isDelLine: false
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-text-height',
        code: 'long-text',
        name: '长文本',
        component: 'YvanRichText',
        propValue:
            '<p><span style="font-size: 16pt;">双击</span><span style="color: rgb(255, 255, 255); background-color: #009688; font-size: 16pt; font-family: 仿宋;">编辑</span><span style="font-size: 16pt;">文本</span></p>',
        style: {
            width: 500,
            height: 200,
            fontSize: 12,
            background: null,
            rotate: 0,
            padding: '0'
        },
        groupStyle: {}
    },
    {
        icon: 'ri-table-2',
        code: 'table',
        name: '单元格',
        component: 'YvanSimpleTable',
        propValue: {},
        style: {
            width: 'auto',
            height: 'auto',
            fontSize: 12,
            background: '#FFFFFF',
            borderWidth: 2,
            borderColor: '#212121',
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-table',
        code: 'complex-table',
        name: '复杂表格',
        component: 'YvanComplexTable',
        propValue: {},
        showPrefix: true,
        showHead: true,
        showFoot: true,
        showSuffix: true,
        style: {
            width: 'auto',
            height: 'auto',
            fontSize: 12,
            fontFamily: 'default',
            color: '#000000',
            background: '#FFFFFF',
            borderWidth: 2,
            borderColor: '#212121',
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-minus',
        code: 'line',
        name: '直线',
        component: 'YvanLine',
        propValue: '',
        style: {
            width: 200,
            height: 1,
            background: '#000',
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-square-o',
        code: 'rectangle',
        name: '矩形',
        component: 'YvanRect',
        propValue: '',
        style: {
            borderRadius: 'inherit',
            borderWidth: 1,
            borderColor: '#212121',
            borderType: 'solid',
            width: 200,
            height: 200,
            background: null,
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-circle-thin',
        code: 'circle',
        name: '圆形',
        component: 'YvanCircle',
        propValue: '',
        style: {
            borderWidth: 1,
            borderColor: '#212121',
            borderType: 'solid',
            width: 200,
            height: 200,
            background: '#ffffff',
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-image',
        code: 'image',
        name: '图片',
        component: 'YvanImage',
        src: '',
        title: '默认图片',
        style: {
            borderRadius: 'inherit',
            borderWidth: 0,
            borderColor: '#212121',
            borderType: 'none',
            width: 200,
            height: 200,
            background: null,
            rotate: 0
        },
        groupStyle: {}
    },
    {
        icon: 'fa fa-barcode',
        code: 'barcode',
        name: '条码',
        component: 'YvanBarcode',
        src: '',
        title: '默认图片',
        style: {
            borderRadius: 'inherit',
            borderWidth: 0,
            borderColor: '#212121',
            borderType: 'none',
            width: 200,
            height: 200,
            background: null,
            rotate: 0
        },
        groupStyle: {}
    }
]

/**
 * 复合组件
 */
export const compositeComponentList = []

/**
 * 其他组件
 */
export const otherComponentList = []

/**
 * 组件类型: 布局组件/基础组件/复合组件/其他组件
 */
export const componentTypeList = [
    {
        name: "layout_component",
        title: "布局组件",
        componentList: layoutComponentList
    },
    {
        name: "basic_component",
        title: "基础组件",
        componentList: basicComponentList
    },
    // {
    //     name: "composite_component",
    //     title: "复合组件",
    //     componentList: compositeComponentList
    // },
    // {
    //     name: "other_component",
    //     title: "其他组件",
    //     componentList: otherComponentList
    // }
]


export const getComponentMap = function () {
    const componentMap = new Map()
    for (const componentType of componentTypeList){
        for (const component of componentType.componentList){
            componentMap.set(component.code, component)
        }
    }
    return componentMap
}
